pub struct DeploymentMethods<'a, S>where
S: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on deployment resources.
It is not used directly, but through the DeploymentManager hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_deploymentmanager2_beta2 as deploymentmanager2_beta2;
use std::default::Default;
use deploymentmanager2_beta2::{DeploymentManager, oauth2, hyper, hyper_rustls, chrono, FieldMask};
let secret: oauth2::ApplicationSecret = Default::default();
let auth = oauth2::InstalledFlowAuthenticator::builder(
secret,
oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = DeploymentManager::new(hyper::Client::builder().build(hyper_rustls::HttpsConnectorBuilder::new().with_native_roots().https_or_http().enable_http1().build()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `insert(...)`, `list(...)`, `patch(...)` and `update(...)`
// to build up your call.
let rb = hub.deployments();Implementations
sourceimpl<'a, S> DeploymentMethods<'a, S>
impl<'a, S> DeploymentMethods<'a, S>
sourcepub fn delete(
&self,
project: &str,
deployment: &str
) -> DeploymentDeleteCall<'a, S>
pub fn delete( &self, project: &str, deployment: &str ) -> DeploymentDeleteCall<'a, S>
Create a builder to help you perform the following task:
Deletes a deployment and all of the resources in the deployment.
Arguments
project- The project ID for this request.deployment- The name of the deployment for this request.
sourcepub fn get(&self, project: &str, deployment: &str) -> DeploymentGetCall<'a, S>
pub fn get(&self, project: &str, deployment: &str) -> DeploymentGetCall<'a, S>
Create a builder to help you perform the following task:
Gets information about a specific deployment.
Arguments
project- The project ID for this request.deployment- The name of the deployment for this request.
sourcepub fn insert(
&self,
request: Deployment,
project: &str
) -> DeploymentInsertCall<'a, S>
pub fn insert( &self, request: Deployment, project: &str ) -> DeploymentInsertCall<'a, S>
Create a builder to help you perform the following task:
Creates a deployment and all of the resources described by the deployment manifest.
Arguments
request- No description provided.project- The project ID for this request.
sourcepub fn list(&self, project: &str) -> DeploymentListCall<'a, S>
pub fn list(&self, project: &str) -> DeploymentListCall<'a, S>
Create a builder to help you perform the following task:
Lists all deployments for a given project.
Arguments
project- The project ID for this request.
sourcepub fn patch(
&self,
request: Deployment,
project: &str,
deployment: &str
) -> DeploymentPatchCall<'a, S>
pub fn patch( &self, request: Deployment, project: &str, deployment: &str ) -> DeploymentPatchCall<'a, S>
Create a builder to help you perform the following task:
Updates a deployment and all of the resources described by the deployment manifest. This method supports patch semantics.
Arguments
request- No description provided.project- The project ID for this request.deployment- The name of the deployment for this request.
sourcepub fn update(
&self,
request: Deployment,
project: &str,
deployment: &str
) -> DeploymentUpdateCall<'a, S>
pub fn update( &self, request: Deployment, project: &str, deployment: &str ) -> DeploymentUpdateCall<'a, S>
Create a builder to help you perform the following task:
Updates a deployment and all of the resources described by the deployment manifest.
Arguments
request- No description provided.project- The project ID for this request.deployment- The name of the deployment for this request.